@@ -17,12 +17,12 @@
 import mock
 
 from fuel_plugin_builder import errors
-from fuel_plugin_builder.tests.base import BaseValidator
+from fuel_plugin_builder.tests.base import LegacyBaseValidatorTestCase
 from fuel_plugin_builder.validators.schemas import SchemaV3
 from fuel_plugin_builder.validators.validator_v3 import ValidatorV3
 
 
-class TestValidatorV3(BaseValidator):
+class TestValidatorV3(LegacyBaseValidatorTestCase):
 
     __test__ = True
     validator_class = ValidatorV3
@@ -549,6 +549,24 @@ class TestValidatorV3(BaseValidator):
             utils_mock, mock_data,
             err_msg, self.validator.check_node_roles_schema)
 
+    @mock.patch('fuel_plugin_builder.validators.base.utils')
+    def test_check_node_role_conflicts(self, utils_mock):
+        utils_mock.parse_yaml.return_value = {
+            'plugin_name': {
+                'name': 'test_plugin',
+                'description': 'test plugin',
+                'conflicts': '*'}}
+
+        self.validator.check_node_roles_schema()
+
+        utils_mock.parse_yaml.return_value = {
+            'plugin_name': {
+                'name': 'test_plugin',
+                'description': 'test plugin',
+                'conflicts': ['some_role']}}
+
+        self.validator.check_node_roles_schema()
+
     @mock.patch('fuel_plugin_builder.validators.base.utils')
     def test_check_valid_volumes_roles_mapping_name(self, utils_mock):
         utils_mock.parse_yaml.return_value = {
