@@ -19,4 +19,5 @@ from fuel_plugin_builder.validators.validator_v1 import ValidatorV1
 from fuel_plugin_builder.validators.validator_v2 import ValidatorV2
 from fuel_plugin_builder.validators.validator_v3 import ValidatorV3
 from fuel_plugin_builder.validators.validator_v4 import ValidatorV4
-from fuel_plugin_builder.validators.base import BaseValidator
+from fuel_plugin_builder.validators.validator_v5 import ValidatorV5
+from fuel_plugin_builder.validators.base import LegacyBaseValidator
